{% extends "eztables/base.html" %}

{% block container %}
<div class="hero-unit">
    <h1>Django ezTables Demo</h1>

    <p class="lead">
        Django ezTables provides easy integration between <a href="http://datatables.net">jQuery DataTables</a> and <a href="http://www.djangoproject.com">Django</a>.
    </p>

    <p>The full documentation is available on <a href="http://django-eztables.readthedocs.org">Read the Docs</a></p>

    <p>Explore Django ezTables usage through these simple demo pages</p>

    <p>
        <a class="btn btn-primary btn-large" href="{% url client-side %}">
            Client-side
        </a>
        <a class="btn btn-primary btn-large" href="{% url server-side %}">
            Server-side
        </a>
        <a class="btn btn-primary btn-large" href="{% url deferred-loading %}">
            Deferred loading
        </a>
        <a class="btn btn-primary btn-large" href="{% url localization %}">
            Localization
        </a>
    </p>

</div>
{% endblock %}
