{% load js staticfiles eztables %}
<!doctype html>
<!--[if lt IE 7]> <html class="no-js lt-ie9 lt-ie8 lt-ie7" lang="en"> <![endif]-->
<!--[if IE 7]>    <html class="no-js lt-ie9 lt-ie8" lang="en"> <![endif]-->
<!--[if IE 8]>    <html class="no-js lt-ie9" lang="en"> <![endif]-->
<!--[if gt IE 8]><!--> <html class="no-js" lang="en"> <!--<![endif]-->
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">

    <title>
        {% block title %}Django EZTables Demo{% endblock %}
    </title>
    <meta name="description" content="Django EZTables Demo">
    <meta name="author" content="Axel Haustant">
    <link rel="shortcut icon" type="image/ico" href="{% static "img/favicon.ico" %}">

    {% css "css/bootstrap.min.css" %}
    {% datatables_bootstrap_css %}
    {% css "css/eztables.demo.css" %}
    {% css "css/solarized_dark.css" %}

    {% block extra_style %}{% endblock %}

    {% js_lib "modernizr-2.5.3-respond-1.1.0.min.js" %}
</head>

<body>
<!--[if lt IE 7]><p class=chromeframe>Your browser is <em>ancient!</em> <a href="http://browsehappy.com/">Upgrade to a different browser</a> or <a href="http://www.google.com/chromeframe/?redirect=true">install Google Chrome Frame</a> to experience this site.</p><![endif]-->

    <header class="navbar navbar-fixed-top">
        <div class="navbar-inner">
            <a class="brand logo" href="{% url index %}" title="EZTables Demo">
                ezTables
            </a>

            <ul class="nav">
                <li class="{% block client-side %}{% endblock %}">
                    <a href="{% url client-side %}">
                        Client-side
                    </a>
                </li>
                <li class="{% block server-side %}{% endblock %}">
                    <a href="{% url server-side %}">
                        Server-side
                    </a>
                </li>
                <li class="{% block deferred-loading %}{% endblock %}">
                    <a href="{% url deferred-loading %}">
                        Deferred loading
                    </a>
                </li >
                <li class="{% block localization %}{% endblock %}">
                    <a href="{% url localization %}">
                        Localization
                    </a>
                </li>
            </ul>
        </div>
    </header>

    <div id="main-container" class="container">
    {% block container %}{% endblock %}
    </div>

    <footer id="footer" class="container-fluid">
      <p>&copy; <a href="http://noirbizarre.info"/>noirbizarre.info</a> 2012</p>
    </footer>

    {% django_js %}
    {% js_lib "bootstrap.min.js" %}
    {% datatables_js %}
    {% datatables_bootstrap_js %}
    {% js_lib "highlight.pack.js" %}
    {% js "js/eztables.demo.js" %}
    {% block extra-script %}{% endblock %}
</body>
</html>
