{% extends "eztables/base.html" %}

{% block deferred-loading %}active{% endblock %}

{% block container %}
<div class="page-header">
    <h2>Deferred loading</h2>
</div>

<div class="row">
    <span class="label label-warning">TODO</span>
</div>

{% endblock %}
